# WARNING - Generated by {fusen} from dev/flat_full.Rmd: do not edit by hand


#' Scale Counts Table
#'
#' This function scales a counts table based on the expected sequencing depth per sample.
#'
#' @param countsTable A counts table containing raw read counts.
#' @param scalingDepth_factor  sequencing depth factor vector
#' @return A scaled counts table.
#'
#' @export
#' @examples
#' mock_data <- list(counts = matrix(c(10, 20, 30, 20, 30, 10, 10, 20, 20, 20, 30, 10), ncol = 4))
#' scaled_counts <- scaleCountsTable(countsTable = mock_data$counts, 2)
#'
scaleCountsTable <- function(countsTable, scalingDepth_factor){
  counts_scaled <- as.data.frame(sweep(as.matrix(countsTable), 2,  scalingDepth_factor, "*"))
  return(counts_scaled)
}



#' Get scaling factor for count normalization
#'
#' Calculates the scaling factor for count normalization based on the sequencing depth.
#'
#' @param countsTable Matrix or data frame of counts data.
#' @param seq_depth Numeric vector containing the sequencing depths.
#' @return Numeric vector of scaling factors for count normalization.
#' @export
get_scaling_factor <- function(countsTable, seq_depth){
  seq_depth_simu <- colSums(countsTable)
  
  if (length(seq_depth) > length(seq_depth_simu))
    message("INFO: The length of the sequencing_depth vector exceeds the number of samples. Only the first N values will be utilized.")
  if (length(seq_depth) < length(seq_depth_simu))
    message("INFO: The length of the sequencing_depth vector is shorter than the number of samples. Values will be recycled.")

  scalingDepth_factor <- suppressWarnings(seq_depth/seq_depth_simu)
  return(scalingDepth_factor)
}



